/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */


package sync4j.framework.core;

import sync4j.framework.tools.Base64;

/**
 * Corresponds to &lt;NextNonce&gt; tag that specifies the nonce string to be 
 * used in any subsequent communication
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: NextNonce.java,v 1.4 2005/03/02 20:57:37 harrie Exp $
 */
public final class NextNonce
implements java.io.Serializable {

    // ------------------------------------------------------------ Private data

    private byte[] value;
    
    // ------------------------------------------------------------ Constructors
    /**
     * For serialization purposes
     */
    protected NextNonce() {
        setValue(new byte[0]);
    }

    /**
     * Creates a new NextNonce object with the given information (as byte[])
     *
     * @param value the value of next nonce NOT NULL
     *
     */
    public NextNonce(final byte[] value) {
        setValue(value);
        }
    
    /**
     * Creates a new NextNonce object with the given information (as String)
     *
     * @param value the value of next nonce NOT NULL
     *
     */
    public NextNonce(final String value) {
        setValueAsString(value);
    }

    // ---------------------------------------------------------- Public methods
    
    /**
     * Gets the value
     * 
     * @return value
     */
    public byte[] getValue() {
        return this.value;
    }
    
    public void setValue(final byte[] value) {
        if (value == null) {
            this.value = new byte[0];
            return;
        }
        
        this.value = value;
    }
    
    public void setValueAsString(final String value) {
        if (value == null) {
            this.value = new byte[0];
            return;
        }
        
        this.value = value.getBytes();
    }

    /**
     * Gets the value in Base64 encoded
     *
     * @return the value in Base64 encoded form
     */
    public String getValueAsBase64() {        
        return new String(Base64.encode(value));
    }
    
    public String toString() {
        return getValueAsBase64();
    }
}
