/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
 */
package sync4j.framework.engine;

import sync4j.framework.engine.SyncItem;
import sync4j.framework.engine.SyncOperationImpl;

/**
 * A synchronization conflict reflects a situation where one item has changed
 * in both the sources involved in the synchronization. See SyncProcess for
 * more details.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SyncConflict.java,v 1.7 2005/03/02 20:57:37 harrie Exp $
 */
public class SyncConflict extends SyncOperationImpl {
    
    // --------------------------------------------------------------- constants
    
    public final static String STATE_DELETED_DELETED   = "DD";
    public final static String STATE_DELETED_UPDATED   = "DU";
    public final static String STATE_DELETED_NEW       = "DN";
    public final static String STATE_DELETED_NONE      = "DX";
    public final static String STATE_DELETED_CONFLICT  = "DC";
    public final static String STATE_UPDATED_DELETED   = "UD";
    public final static String STATE_UPDATED_UPDATED   = "UU";
    public final static String STATE_UPDATED_NEW       = "UN";
    public final static String STATE_UPDATED_NONE      = "UX";
    public final static String STATE_UPDATED_CONFLICT  = "UC";
    public final static String STATE_NEW_DELETED       = "ND";
    public final static String STATE_NEW_UPDATED       = "NU";
    public final static String STATE_NEW_NEW           = "NN";
    public final static String STATE_NEW_NONE          = "NX";
    public final static String STATE_NEW_CONFLICT      = "NC";
    public final static String STATE_NONE_DELETED      = "XD";
    public final static String STATE_NONE_UPDATED      = "XU";
    public final static String STATE_NONE_NEW          = "XN";
    public final static String STATE_NONE_CONFLICT     = "XC";
    public final static String STATE_CONFLICT_DELETED  = "CD";
    public final static String STATE_CONFLICT_UPDATED  = "CU";
    public final static String STATE_CONFLICT_NEW      = "CN";
    public final static String STATE_CONFLICT_NONE     = "CX";
    public final static String STATE_CONFLICT_CONFLICT = "CC";
    

    // -------------------------------------------------------------- Properties
   
    /**
     * The type of this operation
     */
    private String type;
    public String getType() {
        return this.type;
    }
        
    // ------------------------------------------------------------ Constructors

    public SyncConflict() {
    }
    
    public SyncConflict(SyncItem SyncItemA, SyncItem SyncItemB, String type) {
        super(SyncItemA, SyncItemB, CONFLICT);
        
        this.type = type;
    }
}
