/**
 * Copyright (C) 2003-2005 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.framework.server;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This class represent an addressable SyncML source registered to Sync4j.
 * It is not intended to store specific SyncSource information.
 *
 * @author  Stefano Fornari @ Funambol
 *
 * @version $Id: Sync4jSource.java,v 1.5 2005/03/02 20:57:38 harrie Exp $
 */
public class Sync4jSource {

    private String uri;   // the source uri
    private String config; // the source configuration file
    private String sourceTypeId; // the source type id
    private String sourceName; //the source name

    /** Creates a new instance of Sync4jSyncSource */
    public Sync4jSource() {
        this(null, null, null, null);
    }

    public Sync4jSource(String uri) {
        this(uri, null, null, null);
    }

    public Sync4jSource(String uri, String config) {
        this(uri,config, null, null);
    }

    public Sync4jSource(String uri         ,
                        String config      ,
                        String sourceTypeId,
                        String sourceName  ) {
        this.uri    = uri   ;
        this.config = config;
        this.sourceTypeId = sourceTypeId;
        this.sourceName = sourceName;
    }

    /** Getter for property uri.
     * @return Value of property uri.
     *
     */
    public String getUri() {
        return uri;
    }

    /** Setter for property uri.
     * @param uri New value of property uri.
     *
     */
    public void setUri(String uri) {
        int qMark = uri.indexOf('?');
        if (qMark == -1) {
            this.uri = uri;
        } else {
            this.uri = uri.substring(0, qMark);
        }
    }

    /** Getter for property config.
     * @return Value of property config.
     *
     */
    public String getConfig() {
        return config;
    }

    /** Setter for property config.
     * @param config New value of property config.
     *
     */
    public void setConfig(String config) {
        this.config = config;
    }

    /** Getter for property sourceTypeId.
     * @return Value of property sourceTypeId.
     *
     */
    public String getSourceTypeId() {
        return sourceTypeId;
    }

    /** Setter for property sourceTypeId.
     * @param sourceTypeId New value of property sourceTypeId.
     *
     */
    public void setSourceTypeId(String sourceTypeId) {
        this.sourceTypeId = sourceTypeId;
    }

    /** Getter for property sourceName.
     * @return Value of property sourceName.
     *
     */
    public String getSourceName() {
        return sourceName;
    }

    /** Setter for property sourceName.
     * @param sourceName New value of property sourceName.
     *
     */
    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }

    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

         sb.append("uri",     uri  );
         sb.append("config", config);
         sb.append("sourceTypeId", sourceTypeId);
         sb.append("sourceName", sourceName);

         return sb.toString();
    }

}
